#[repr(i32)]pub enum MessageType {
Ack = 0,
CollectInterval = 160,
BeepOn = 161,
BeepOff = 162,
Shutdown = 163,
PowerOn = 164,
Scd41Temp = 176,
Scd41Humidity = 177,
Scd41Co2 = 178,
Aht20Temp = 179,
Aht20Humidity = 180,
TvocIndex = 181,
}Variants
Ack = 0
CollectInterval = 160
in ms
BeepOn = 161
duration ms
BeepOff = 162
cancel prematurely
Shutdown = 163
PowerOn = 164
Scd41Temp = 176
Scd41Humidity = 177
Scd41Co2 = 178
Aht20Temp = 179
Aht20Humidity = 180
TvocIndex = 181
Implementations
Sourceimpl MessageType
impl MessageType
Sourceimpl MessageType
impl MessageType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.